@@ -1,8 +1,7 @@
-from typing import Optional, Union
+import logging
 
 import numpy
 import pandas
-from pmdarima import AutoARIMA
 from scipy.special._ufuncs import inv_boxcox
 from scipy.stats import boxcox
 from statsmodels.tsa.holtwinters import ExponentialSmoothing
@@ -13,6 +12,8 @@ from hts._t import Model, TimeSeriesModelT, TransformT
 from hts.transforms import FunctionTransformer
 from hts.hierarchy import HierarchyTree
 
+logger = logging.getLogger(__name__)
+
 
 class TimeSeriesModel(TimeSeriesModelT):
     """ Base class for the implementation of the underlying models.
@@ -76,6 +77,12 @@ class TimeSeriesModel(TimeSeriesModelT):
             model = ExponentialSmoothing(endog=data, **kwargs)
 
         elif self.kind == Model.auto_arima.name:
+            try:
+                from pmdarima import AutoARIMA
+            except ImportError:  # pragma: no cover
+                logger.error('pmdarima not installed, so auto_arima won\'t work. Exiting.'
+                             'Install it with: pip install scikit-hts[auto_arima]')
+                return
             model = AutoARIMA(**kwargs)
 
         elif self.kind == Model.sarimax.name:
@@ -97,4 +104,4 @@ class TimeSeriesModel(TimeSeriesModelT):
         raise NotImplementedError
 
     def fit_predict(self, node: HierarchyTree, **kwargs):
-        return self.fit().predict(node)
\ No newline at end of file
+        return self.fit().predict(node)
