@@ -4,13 +4,12 @@ from hts import HTSRegressor
 from hts.revision import RevisionMethod
 
 
-def test_instantiate_revision(load_df_and_hier_uv):
-    hierarchical_sine_data, sine_hier = load_df_and_hier_uv
-    hsd = hierarchical_sine_data.head(200)
+def test_instantiate_revision(load_df_and_hier_visnights):
+    hierarchical_visnights_data, visnights_hier = load_df_and_hier_visnights
 
     for method in ['OLS', 'FP', 'WLSS', 'WLSV', 'PHA', 'AHP', 'NONE']:
         ht = HTSRegressor(model='holt_winters', revision_method=method)
-        ht.fit(df=hsd, nodes=sine_hier)
+        ht.fit(df=hierarchical_visnights_data, nodes=visnights_hier)
 
         rm = RevisionMethod(method, sum_mat=ht.sum_mat, transformer=ht.transform)
 
@@ -21,4 +20,4 @@ def test_instantiate_revision(load_df_and_hier_uv):
             nodes=ht.nodes
         )
         assert isinstance(revised, numpy.ndarray)
-        assert revised.shape == (203, len(ht.hts_result.forecasts))
+        assert revised.shape == (11, len(ht.hts_result.forecasts))
